Pre-defined pairs of subgroups commonly used for achievement gap calculations. Each pair consists of c(reference_group, comparison_group) where gap = reference - comparison.
Pre-defined pairs of subgroups commonly used for achievement gap calculations. Each pair consists of c(reference_group, comparison_group) where gap = reference - comparison.