Skip to contents

Calculates the percentage of public school students enrolled in charter schools for each host city over time.

Usage

charter_market_share(df_enrollment, year_col = "end_year")

Arguments

df_enrollment

Enrollment data with charter sector and all-public aggregates (combine fetch_enr() output with charter_sector_enr_aggs() and allpublic_enr_aggs())

year_col

Character. Year column. Default "end_year".

Value

Dataframe with charter market share by city and year