Skip to contents

Extract Report Card CDS

Usage

extract_rc_cds(list_of_prs)

Arguments

list_of_prs

output of get_rc_databases (ie, a list where each element is) a list of data.frames

Value

data frame with county, district and school ids and identifiers for all years present in the input