Skip to contents

Convenience function to download and combine all available chronic absenteeism data into a single data frame.

Usage

fetch_all_chronic_absenteeism()

Value

A data frame with all chronic absenteeism results (2017-2019, 2022-2024)

Examples

if (FALSE) { # \dontrun{
# Get all chronic absenteeism data
all_ca <- fetch_all_chronic_absenteeism()
} # }