fetch_njask is a wrapper around get_raw_njask and
process_nj_assess that passes the correct file layout data to each function,
given an end_year and grade.
fetch_njask is a wrapper around get_raw_njask and
process_nj_assess that passes the correct file layout data to each function,
given an end_year and grade.