Skip to contents

Aggregate multiple grad count rows and produce summary statistics

Usage

gcount_aggregate_calcs(df)

Arguments

df

grouped df of gcount data

Value

df with aggregate stats for whatever grouping was provided