internal/helper function to facilitate the extraction of relevant `assessment_peer_percentile` columns when calculating state/dfg-wide percentiles
internal/helper function to facilitate the extraction of relevant `assessment_peer_percentile` columns when calculating state/dfg-wide percentiles