R/report_card.R
extract_rc_cds.Rd
Extract Report Card CDS
extract_rc_cds(list_of_prs)
output of get_rc_databases (ie, a list where each element is) a list of data.frames
data frame with county, district and school ids and identifiers for all years present in the input