R/fetch_assessment.R
fetch_all_chronic_absenteeism.Rd
Convenience function to download and combine all available chronic absenteeism data into a single data frame.
fetch_all_chronic_absenteeism()
A data frame with all chronic absenteeism results (2017-2019, 2022-2024)
if (FALSE) { # \dontrun{ # Get all chronic absenteeism data all_ca <- fetch_all_chronic_absenteeism() } # }