fetch_gepa is a wrapper around get_raw_gepa and
process_nj_assess that passes the correct file layout data to each function,
given a end_year and grade.
fetch_gepa is a wrapper around get_raw_gepa and
process_nj_assess that passes the correct file layout data to each function,
given a end_year and grade.