Program codes used by the New Jersey Department of Education for student enrollment
reporting. Includes grade levels, special education programs, and other educational
programs.
A compilation of all the "program codes" used by the state of NJ. example:
http://www.nj.gov/education/data/enr/enr15/stat_doc.htm
A data frame with 682 rows and 3 columns:
- end_year
School year ending year
- program_code
Two-digit program code
- program_name
Program name or description
- end_year
end_year
- program_code
program_code
- program_name
program_name
#'
NJ Department of Education
NJDOE website for each year of enrollment data (see link above)